from enum import Enum

class ContentStatus(Enum):
    """ Specifies the state of a content (discarded, published, ...).

    :var DISCARDED: The content was discarded, and is no subject for publishing.
    :var IN_PROGRESS: The content is in the process of being written. It *should* not be published now.
    :var READY: The content is ready for publishing.
    :var PUBLISHED: The content was published, and is available for the public.
    """
    DISCARDED = "-2"
    IN_PROGRESS = "-1"
    READY = "0"
    PUBLISHED = "1"


class ContentType(Enum):
    """ Specifies the type of a content. A content can be a news, a tutorial, an
    information, ... .

    :var TUTORIAL: The content's purpose is to help its readers with some parts of the game ("Spielhilfe" in German).
    :var GAME_ANNOUNCEMENT: The content announces a new game, and features basic information about it ("Spielvorstellung" in German).
    :var NEWS: The content is a news article.
    :var COLUMN: Not in use.
    :var INFORMATION: The content informs the user about certain aspects of the game or its mechanics.
    :var BOILERPLATE: The content is meant to be included in other contents ("Textbaustein" in German).
    :var SPECIAL: The content serves a special purpose ("Spezialelement" in German).
    """
    
    TUTORIAL = "spielhilfe"
    GAME_ANNOUNCEMENT = "review"
    NEWS = "news"
    COLUMN = "kolumne"
    INFORMATION = "information"
    BOILERPLATE = "boilerplate"
    SPECIAL = "element"


class ContentPublishMethod(Enum):
    """ Specifies how a content should be published.

    :var STANDARD:
    :var FEATURE: Specifies that a content should be featured on the index page.
    """

    NO_FRONTPAGE = "-1"
    STANDARD = "0"
    STICKY = "1"
    FEATURE = "2"


class Order(Enum):
    """ Specifies the ordering of lists returned by the API.

    :var ASCENDING:
    :var DESCENDING:
    """

    ASCENDING = "asc"
    DESCENDING = "desc"